# arpes.utilities.normalize module

**arpes.utilities.normalize.normalize\_to\_spectrum(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\])**

**arpes.utilities.normalize.normalize\_to\_dataset(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\])**
